@@ -2,8 +2,10 @@ from __future__ import annotations
 
 from typing import Any, ClassVar
 
-import requests
+import httpx
+from httpx._types import HeaderTypes
 
+from deezer.auth import DeezerQueryAuth
 from deezer.exceptions import (
     DeezerErrorResponse,
     DeezerHTTPError,
@@ -26,7 +28,7 @@ from deezer.resources import (
 )
 
 
-class Client:
+class Client(httpx.Client):
     """
     A client to retrieve some basic infos about Deezer resources.
 
@@ -34,7 +36,7 @@ class Client:
     be passed in to the constructor as kwargs.
 
         >>> import deezer
-        >>> client = deezer.Client(app_id='foo', app_secret='bar')
+        >>> client = deezer.Client()
 
     This client provides several methods to retrieve the content most
     kinds of Deezer objects, based on their json structure.
@@ -45,8 +47,6 @@ class Client:
         >>> import deezer
         >>> client = deezer.Client(headers={'Accept-Language': 'fr'})
 
-    :param app_id: application ID.
-    :param app_secret: application secret.
     :param access_token: user access token.
     :param headers: a dictionary of headers to be used.
     """
@@ -66,18 +66,21 @@ class Client:
         "track": Track,
         "user": User,
     }
-    base_url = "https://api.deezer.com"
 
     def __init__(
-        self, app_id=None, app_secret=None, access_token=None, headers=None, **kwargs
+        self,
+        access_token: str | None = None,
+        headers: HeaderTypes | None = None,
     ):
-        self.app_id = app_id
-        self.app_secret = app_secret
-        self.access_token = access_token
-        self.session = requests.Session()
-
-        headers = headers or {}
-        self.session.headers.update(headers)
+        if access_token:
+            deezer_auth = DeezerQueryAuth(access_token=access_token)
+        else:
+            deezer_auth = None
+        super().__init__(
+            base_url="https://api.deezer.com",
+            auth=deezer_auth,
+            headers=headers,
+        )
 
     def _process_json(
         self,
@@ -98,9 +101,7 @@ class Client:
         :returns: instance of :class:`~deezer.Resource`
         """
         if "data" in item:
-            parsed_data = [
-                self._process_json(i, parent, paginate_list=False) for i in item["data"]
-            ]
+            parsed_data = [self._process_json(i, parent, paginate_list=False) for i in item["data"]]
             if not paginate_list:
                 return parsed_data
             item["data"] = parsed_data
@@ -139,7 +140,7 @@ class Client:
         resource_type: type[Resource] | None = None,
         resource_id: int | None = None,
         paginate_list=False,
-        **params,
+        **kwargs,
     ):
         """
         Make a request to the API and parse the response.
@@ -150,23 +151,20 @@ class Client:
         :param resource_type: The resource class to use as top level.
         :param resource_id: The resource id to use as top level.
         :param paginate_list: Whether to wrap list into a pagination object.
-        :param params: Query parameters to add to the request
         """
-        if self.access_token is not None:
-            params["access_token"] = str(self.access_token)
-        response = self.session.request(
+        response = super().request(
             method,
-            f"{self.base_url}/{path}",
-            params=params,
+            path,
+            **kwargs,
         )
         try:
             response.raise_for_status()
-        except requests.HTTPError as exc:
+        except httpx.HTTPStatusError as exc:
             raise DeezerHTTPError.from_http_error(exc) from exc
         json_data = response.json()
         if not isinstance(json_data, dict):
             return json_data
-        if "error" in json_data and json_data["error"]:
+        if json_data.get("error"):
             raise DeezerErrorResponse(json_data)
         return self._process_json(
             json_data,
@@ -176,8 +174,8 @@ class Client:
             paginate_list=paginate_list,
         )
 
-    def _get_paginated_list(self, path, **params):
-        return PaginatedList(client=self, base_path=path, **params)
+    def _get_paginated_list(self, path: str, params: dict | None = None):
+        return PaginatedList(client=self, base_path=path, params=params)
 
     def get_album(self, album_id: int) -> Album:
         """
@@ -204,9 +202,7 @@ class Client:
         :param genre_id: the genre ID, default to `All` genre (genre_id = 0).
         :returns: a :class:`~deezer.Chart` instance.
         """
-        return self.request(
-            "GET", f"chart/{genre_id}", resource_type=Chart, resource_id=genre_id
-        )
+        return self.request("GET", f"chart/{genre_id}", resource_type=Chart, resource_id=genre_id)
 
     def get_tracks_chart(self, genre_id: int = 0) -> list[Track]:
         """
@@ -359,9 +355,7 @@ class Client:
         :returns: a :class:`PaginatedList <deezer.PaginatedList>`
                   of :class:`Track <deezer.Track>` instances
         """
-        return PaginatedList(
-            client=self, base_path="user/me/recommendations/tracks", **kwargs
-        )
+        return PaginatedList(client=self, base_path="user/me/recommendations/tracks", **kwargs)
 
     def get_user_recommended_albums(self, **kwargs) -> PaginatedList[Album]:
         """
@@ -370,9 +364,7 @@ class Client:
         :returns: a :class:`PaginatedList <deezer.PaginatedList>`
                   of :class:`Track <deezer.Album>` instances
         """
-        return PaginatedList(
-            client=self, base_path="user/me/recommendations/albums", **kwargs
-        )
+        return PaginatedList(client=self, base_path="user/me/recommendations/albums", **kwargs)
 
     def get_user_recommended_artists(self, **kwargs) -> PaginatedList[Artist]:
         """
@@ -381,9 +373,7 @@ class Client:
         :returns: a :class:`PaginatedList <deezer.PaginatedList>`
                   of :class:`Track <deezer.Artist>` instances
         """
-        return PaginatedList(
-            client=self, base_path="user/me/recommendations/artists", **kwargs
-        )
+        return PaginatedList(client=self, base_path="user/me/recommendations/artists", **kwargs)
 
     def get_user_recommended_playlists(self, **kwargs) -> PaginatedList[Playlist]:
         """
@@ -392,9 +382,7 @@ class Client:
         :returns: a :class:`PaginatedList <deezer.PaginatedList>`
                   of :class:`Track <deezer.Playlist>` instances
         """
-        return PaginatedList(
-            client=self, base_path="user/me/recommendations/playlists", **kwargs
-        )
+        return PaginatedList(client=self, base_path="user/me/recommendations/playlists", **kwargs)
 
     def get_user_flow(self, **kwargs) -> PaginatedList[Track]:
         """
@@ -423,7 +411,7 @@ class Client:
         :param album_id: the ID of the album to add.
         :return: boolean whether the operation succeeded.
         """
-        return self.request("POST", "user/me/albums", album_id=album_id)
+        return self.request("POST", "user/me/albums", params={"album_id": album_id})
 
     def remove_user_album(self, album_id: int) -> bool:
         """
@@ -432,7 +420,7 @@ class Client:
         :param album_id: the ID of the album to remove.
         :return: boolean whether the operation succeeded.
         """
-        return self.request("DELETE", "user/me/albums", album_id=album_id)
+        return self.request("DELETE", "user/me/albums", params={"album_id": album_id})
 
     def get_user_artists(self, user_id: int | None = None) -> PaginatedList[Artist]:
         """
@@ -452,7 +440,7 @@ class Client:
         :param artist_id: the ID of the artist to add.
         :return: boolean whether the operation succeeded.
         """
-        return self.request("POST", "user/me/artists", artist_id=artist_id)
+        return self.request("POST", "user/me/artists", params={"artist_id": artist_id})
 
     def remove_user_artist(self, artist_id: int) -> bool:
         """
@@ -461,7 +449,11 @@ class Client:
         :param artist_id: the ID of the artist to remove.
         :return: boolean whether the operation succeeded.
         """
-        return self.request("DELETE", "user/me/artists", artist_id=artist_id)
+        return self.request(
+            "DELETE",
+            "user/me/artists",
+            params={"artist_id": artist_id},
+        )
 
     def get_user_followers(self, user_id: int | None = None) -> PaginatedList[User]:
         """
@@ -492,7 +484,7 @@ class Client:
         :param user_id: the ID of the user to follow.
         :return: boolean whether the operation succeeded.
         """
-        return self.request("POST", "user/me/followings", user_id=user_id)
+        return self.request("POST", "user/me/followings", params={"user_id": user_id})
 
     def remove_user_following(self, user_id: int) -> bool:
         """
@@ -501,7 +493,7 @@ class Client:
         :param user_id: the ID of the user to stop following.
         :return: boolean whether the operation succeeded.
         """
-        return self.request("DELETE", "user/me/followings", user_id=user_id)
+        return self.request("DELETE", "user/me/followings", params={"user_id": user_id})
 
     def get_user_history(self) -> PaginatedList[Track]:
         """
@@ -530,7 +522,7 @@ class Client:
         :param track_id: the ID of the track to add.
         :return: boolean whether the operation succeeded.
         """
-        return self.request("POST", "user/me/tracks", track_id=track_id)
+        return self.request("POST", "user/me/tracks", params={"track_id": track_id})
 
     def remove_user_track(self, track_id: int) -> bool:
         """
@@ -539,7 +531,7 @@ class Client:
         :param track_id: the ID of the track to remove.
         :return: boolean whether the operation succeeded.
         """
-        return self.request("DELETE", "user/me/tracks", track_id=track_id)
+        return self.request("DELETE", "user/me/tracks", params={"track_id": track_id})
 
     def remove_user_playlist(self, playlist_id: int) -> bool:
         """
@@ -548,7 +540,7 @@ class Client:
         :param playlist_id: the ID of the playlist to remove.
         :return: boolean whether the operation succeeded.
         """
-        return self.request("DELETE", "user/me/playlists", playlist_id=playlist_id)
+        return self.request("DELETE", "user/me/playlists", params={"playlist_id": playlist_id})
 
     def add_user_playlist(self, playlist_id: int) -> bool:
         """
@@ -557,7 +549,7 @@ class Client:
         :param playlist_id: the ID of the playlist to add.
         :return: boolean whether the operation succeeded.
         """
-        return self.request("POST", "user/me/playlists", playlist_id=playlist_id)
+        return self.request("POST", "user/me/playlists", params={"playlist_id": playlist_id})
 
     def create_playlist(self, playlist_name) -> int:
         """
@@ -566,7 +558,7 @@ class Client:
         :param playlist_name: the name of the playlist.
         :return: the ID of the playlist that was created
         """
-        result = self.request("POST", "user/me/playlists", title=playlist_name)
+        result = self.request("POST", "user/me/playlists", params={"title": playlist_name})
         # Note: the REST API call returns a dict with just the "id" key in it,
         # so we return that instead of the full Playlist object
         return result.id
@@ -597,15 +589,15 @@ class Client:
         if query:
             query_parts.append(query)
         query_parts.extend(
-            f'{param_name}:"{param_value}"'
-            for param_name, param_value in advanced_params.items()
-            if param_value
+            f'{param_name}:"{param_value}"' for param_name, param_value in advanced_params.items() if param_value
         )
 
         return self._get_paginated_list(
             path=f"search/{path}" if path else "search",
-            q=" ".join(query_parts),
-            **optional_params,
+            params={
+                "q": " ".join(query_parts),
+                **optional_params,
+            },
         )
 
     def search(
